@@ -422,9 +422,9 @@ plot.PCA <- function(x, fac, xax=1, yax=2,
   if (box) box()
   # we return a df
   if (is.null(fac))
-    invisible(dplyr::data_frame(x=xy[, 1], y=xy[, 2]))
+    invisible(dplyr::tibble(x=xy[, 1], y=xy[, 2]))
   else
-    invisible(dplyr::data_frame(x=xy[, 1], y=xy[, 2], fac=fac))
+    invisible(dplyr::tibble(x=xy[, 1], y=xy[, 2], fac=fac))
 }
 
 # Boxplot ---------
@@ -597,7 +597,7 @@ scree.PCA <- function(x, nax){
     nax <- 1:length(eig)
   }
   # return a data_frame
-  dplyr::data_frame(axis=nax,
+  dplyr::tibble(axis=nax,
                     proportion=eig[nax],
                     cumsum=cumsum(eig)[nax])
 }
@@ -613,7 +613,7 @@ scree.LDA <- function(x, nax){
     nax <- 1:length(eig)
   }
   # return a data_frame
-  dplyr::data_frame(axis=nax,
+  dplyr::tibble(axis=nax,
                     proportion=eig[nax],
                     cumsum=cumsum(eig)[nax])
 
