@@ -507,39 +507,119 @@ PCA2shp_procrustes <- function(pos, rot, mshape, amp.shp = 1) {
 # @param pts.shp number of points to reconstruct the shape
 # @rdname LDA2shp_fourier
 # @export
-LDA2shp_efourier <- function(pos, rot, mshape, amp.shp = 1, pts.shp = 60) {
-  if (ncol(pos) != ncol(rot))
-    stop("'rot' and 'pos' must have the same ncol")
-  if (length(mshape) != nrow(rot))
-    stop("'mshape' and ncol(rot) lengths differ")
-  nb.h <- length(mshape)/4
-  n <- nrow(pos)
-  # we prepare the array
-  res <- list()
-  for (i in 1:n) {
-    ax.contrib <- .mprod(rot, pos[i, ]) * amp.shp
-    coe <- mshape + apply(ax.contrib, 1, sum)
-    xf <- coeff_split(coe)
-    coo <- efourier_i(xf, nb.h = nb.h, nb.pts = pts.shp)
-    # reconstructed shapes are translated on their centroid if
-    # (trans) {
-    dx <- pos[i, 1] - coo_centpos(coo)[1]
-    dy <- pos[i, 2] - coo_centpos(coo)[2]
-    coo <- coo_trans(coo, dx, dy)
-    # }
-    res[[i]] <- coo
-  }
-  return(res)
-}
 
-# @rdname LDA2shp_fourier
-# @export
-LDA2shp_rfourier <- function() {
-}
+# with layerize, I think LDA2shp_* equals PCA2shp_*
+# apropos("PCA2shp_") %>% paste(gsub("PCA", "LDA", .), "<-", .) %>% cat(sep="\n")
+LDA2shp_dfourier    <- PCA2shp_dfourier
+LDA2shp_efourier    <- PCA2shp_efourier
+LDA2shp_polynomials <- PCA2shp_polynomials
+LDA2shp_procrustes  <- PCA2shp_procrustes
+LDA2shp_rfourier    <- PCA2shp_rfourier
+LDA2shp_sfourier    <- PCA2shp_sfourier
+LDA2shp_tfourier    <- PCA2shp_tfourier
 
-# @rdname LDA2shp_fourier
-# @export
-LDA2shp_tfourier <- function() {
-}
+# LDA2shp_efourier <- function(pos, rot, mshape, amp.shp = 1, pts.shp = 60) {
+#   if (ncol(pos) != ncol(rot))
+#     stop("'rot' and 'pos' must have the same ncol")
+#   if (length(mshape) != nrow(rot))
+#     stop("'mshape' and ncol(rot) lengths differ")
+#   nb.h <- length(mshape)/4
+#   n <- nrow(pos)
+#   # we prepare the array
+#   res <- list()
+#   for (i in 1:n) {
+#     ax.contrib <- .mprod(rot, pos[i, ]) * amp.shp
+#     coe <- mshape + apply(ax.contrib, 1, sum)
+#     xf <- coeff_split(coe)
+#     coo <- efourier_i(xf, nb.h = nb.h, nb.pts = pts.shp)
+#     # reconstructed shapes are translated on their centroid if
+#     # (trans) {
+#     dx <- pos[i, 1] - coo_centpos(coo)[1]
+#     dy <- pos[i, 2] - coo_centpos(coo)[2]
+#     coo <- coo_trans(coo, dx, dy)
+#     # }
+#     res[[i]] <- coo
+#   }
+#   return(res)
+# }
+#
+# # @rdname LDA2shp_fourier
+# # @export
+# LDA2shp_rfourier <- function(pos, rot, mshape, amp.shp = 1, pts.shp = 60) {
+#   if (ncol(pos) != ncol(rot))
+#     stop("'rot' and 'pos' must have the same ncol")
+#   if (length(mshape) != nrow(rot))
+#     stop("'mshape' and ncol(rot) lengths differ")
+#   nb.h <- length(mshape)/4
+#   n <- nrow(pos)
+#   # we prepare the array
+#   res <- list()
+#   for (i in 1:n) {
+#     ax.contrib <- .mprod(rot, pos[i, ]) * amp.shp
+#     coe <- mshape + apply(ax.contrib, 1, sum)
+#     xf <- coeff_split(coe)
+#     coo <- rfourier_i(xf, nb.h = nb.h, nb.pts = pts.shp)
+#     # reconstructed shapes are translated on their centroid if
+#     # (trans) {
+#     dx <- pos[i, 1] - coo_centpos(coo)[1]
+#     dy <- pos[i, 2] - coo_centpos(coo)[2]
+#     coo <- coo_trans(coo, dx, dy)
+#     # }
+#     res[[i]] <- coo
+#   }
+#   return(res)
+# }
+#
+# # @rdname LDA2shp_fourier
+# # @export
+# LDA2shp_tfourier <- function(pos, rot, mshape, amp.shp = 1, pts.shp = 60) {
+#   if (ncol(pos) != ncol(rot))
+#     stop("'rot' and 'pos' must have the same ncol")
+#   if (length(mshape) != nrow(rot))
+#     stop("'mshape' and ncol(rot) lengths differ")
+#   nb.h <- length(mshape)/4
+#   n <- nrow(pos)
+#   # we prepare the array
+#   res <- list()
+#   for (i in 1:n) {
+#     ax.contrib <- .mprod(rot, pos[i, ]) * amp.shp
+#     coe <- mshape + apply(ax.contrib, 1, sum)
+#     xf <- coeff_split(coe)
+#     coo <- tfourier_i(xf, nb.h = nb.h, nb.pts = pts.shp)
+#     # reconstructed shapes are translated on their centroid if
+#     # (trans) {
+#     dx <- pos[i, 1] - coo_centpos(coo)[1]
+#     dy <- pos[i, 2] - coo_centpos(coo)[2]
+#     coo <- coo_trans(coo, dx, dy)
+#     # }
+#     res[[i]] <- coo
+#   }
+#   return(res)
+# }
+#
+# LDA2shp_sfourier <- function(pos, rot, mshape, amp.shp = 1, pts.shp = 60) {
+#   if (ncol(pos) != ncol(rot))
+#     stop("'rot' and 'pos' must have the same ncol")
+#   if (length(mshape) != nrow(rot))
+#     stop("'mshape' and ncol(rot) lengths differ")
+#   nb.h <- length(mshape)/4
+#   n <- nrow(pos)
+#   # we prepare the array
+#   res <- list()
+#   for (i in 1:n) {
+#     ax.contrib <- .mprod(rot, pos[i, ]) * amp.shp
+#     coe <- mshape + apply(ax.contrib, 1, sum)
+#     xf <- coeff_split(coe)
+#     coo <- sfourier_i(xf, nb.h = nb.h, nb.pts = pts.shp)
+#     # reconstructed shapes are translated on their centroid if
+#     # (trans) {
+#     dx <- pos[i, 1] - coo_centpos(coo)[1]
+#     dy <- pos[i, 2] - coo_centpos(coo)[2]
+#     coo <- coo_trans(coo, dx, dy)
+#     # }
+#     res[[i]] <- coo
+#   }
+#   return(res)
+# }
 
 ##### end morphospaces
